# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 15:26:44 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biosteam import SolidsCentrifuge, System
from biorefineries.corn import create_system

__all__ = ('CornDryGrind',)

class CornDryGrind(ProcessBlock):
    
    def __init__(self, ID='corn_dry_grind', primary_inlet_name='corn'):
        self._primary_inlet_name = primary_inlet_name
        create_function = get_corn_system_upto_slurry
        base_TEA_year = 2018
        N_ins = 7
        N_outs = 3
        inlets = {'corn':6}
        outlets = {'slurry: glucose':1}
        boiler = [0]
        wastewater = [2]
        ignored_HXN = []
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )


def get_corn_system_upto_slurry(ID='corn_system_upto_slurry'):
    sys = create_system()
    sys.simulate()
    f = sys.flowsheet
    disconnect_outs_0_sink = [f.MX, f.P502, f.S1,
                              f.P304, # exclude ammonia addition
                              ]
    include_upstream_of = [f.P322]
    unit_set = set()
    for i in disconnect_outs_0_sink: i.outs[0].disconnect_sink()
    for i in include_upstream_of: 
        unit_set = unit_set.union(i.get_upstream_units())
        unit_set.add(i)
    unit_set.remove(f.E401)
    
    units_to_remove = list(f.E413.get_downstream_units().intersection(f.S1.get_upstream_units()))
    for i in units_to_remove: 
        try: unit_set.remove(i)
        except: pass
    
    f.V310-0-2-f.V321
    more_units_to_remove = [f.P407, f.E316, f.V317, f.P318,
                            f.V303, f.P304, # exclude ammonia addition
                            ]
    for i in more_units_to_remove: 
        try: unit_set.remove(i)
        except: pass
    
    # # include this heat exchanger if including ammonia addition; slurry has V>1 in some cases, leading to evaporator (F301) issues
    # H201 = bst.HXutility('H201', ins=f.P322-0, V=0., rigorous=True)
    # @H201.add_specification(run=False)
    # def H201_feed_vle_spec():
    #     H201_feed = H201.ins[0]
    #     H201_feed.vle(H=H201_feed.H, P=H201_feed.P)
    #     H201._run()
    # unit_set.add(H201)
    
    S201 = SolidsCentrifuge('S201', ins=f.P322-0, outs=('insoluble_proteins', 'slurry_to_fermentation_process'),
                                moisture_content=0.05,
                                split={'InsolubleProtein':0.85},
                                )
    unit_set.add(S201)
    
    corn_system_upto_slurry = System.from_units(ID, list(unit_set))
    for i in corn_system_upto_slurry.outs: i.disconnect_sink()
    # f.HX101.rigorous=True
    corn_system_upto_slurry.simulate(update_configuration=True)
    
    return corn_system_upto_slurry



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarang.bhagwat.git@gmail.com>
# 
# This module is under the UIUC open-source license. See 
# https://github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE
# for license details.
"""
"""

from . import ethanol_separation
from .ethanol_separation import *
from . import HP_solution_separation
from .HP_solution_separation import *
from . import HP_salt_separation
from .HP_salt_separation import *
from . import TAL_separation
from .TAL_separation import *



__all__ = (
    *ethanol_separation.__all__,\
    *HP_solution_separation.__all__,
    *HP_salt_separation.__all__,
    *TAL_separation.__all__,
)



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 15:26:44 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biosteam import System, Unit, Mixer, Stream

__all__ = ('DextroseMonohydrateReceiving',)

class DextroseMonohydrateReceiving(ProcessBlock):
    
    def __init__(self, ID='dextrose_monohydrate_receiving',):
        create_function = create_dextrose_monohydrate_receiving_system
        base_TEA_year = 2019
        N_ins = 7
        N_outs = 3
        inlets = {'dextrose monohydrate':0}
        outlets = {'sugars: dextrose monohydrate':0}
        boiler = []
        wastewater = []
        ignored_HXN = []
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )

def create_dextrose_monohydrate_receiving_system(ID):
    feedstock = Stream('dextrose_monoydrate', Glucose=1., Water=1., units='kmol/h')
    feedstock.price = 0.282524*0.909 # price is 2019$ # dextrose monohydrate stream is 90.9 wt% glucose
    feedstock.F_mass = 200_000 # initial value
    
    U101 = Unit('U101', ins=feedstock, outs='')
    @U101.add_specification(run=False)
    def U101_spec():
        U101.outs[0].copy_like(U101.ins[0])
    
    M201 = Mixer('M201', ins=(U101-0, ''), outs='') # bst.UnitGroup.get_material_cost uses bst.utils.get_inlet_origin; i.e., assumes source unit is a storage unit (i.e., attributes material cost to downstream unit) if len(source.ins) == len(source.outs) == 1 and 'processing' not in source.line.lower()
    
    return System.from_units(ID, [U101, M201])



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 15:33:50 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biosteam import System
from biorefineries.cellulosic.units import Saccharification
from biorefineries.cornstover import create_saccharification_system

__all__ = ('CellulosicEnzymaticSaccharification',)


class CellulosicEnzymaticSaccharification(ProcessBlock):
    
    def __init__(self, ID='cellulosic_enzymatic_saccharification'):
        create_function = get_cornstover_saccharification_system_full
        base_TEA_year = 2007
        N_ins = 3
        N_outs = 1
        inlets = {i: 0 for i in ['pretreated cellulosic stream']}
        outlets = {'slurry: glucose, xylose':0}
        boiler = []
        wastewater = []
        ignored_HXN = []
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )


def get_cornstover_saccharification_system_full(ID='cornstover_saccharification_sys', ins=()):
    sys_upto_presacch = create_saccharification_system(ins=ins)
    sys_upto_presacch.simulate()
    R305 = Saccharification('R305', ins=sys_upto_presacch-0)
    cornstover_saccharification_sys = System.from_units('cornstover_saccharification_sys', 
                                                            sys_upto_presacch.units+[R305])
    
    return cornstover_saccharification_sys



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 16:52:34 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biorefineries.TAL.process_areas import create_TAL_separation_solubility_exploit_process
from biosteam import System, Splitter, HXutility

__all__ = ('TALHotSeparation', 'TALCooledSeparation')

class TALHotSeparation(ProcessBlock):
    def __init__(self, ID='TAL_hot_separation', primary_inlet_name='broth: TAL'):
        self._primary_inlet_name = primary_inlet_name
        create_function = create_TAL_separation_solubility_exploit_process
        base_TEA_year = 2019
        N_ins = 4
        N_outs = 6
        inlets = {'broth: TAL':0}
        outlets = {'hot TAL':4}
        boiler = [1]
        wastewater = [2, 3, 5]
        ignored_HXN = ['H401', 'C401']
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )

class TALCooledSeparation(ProcessBlock):
    def __init__(self, ID='TAL_cooled_separation', primary_inlet_name='broth: TAL'):
        self._primary_inlet_name = primary_inlet_name
        create_function = create_TAL_cooled_separation_solubility_exploit_process
        base_TEA_year = 2019
        N_ins = 6
        N_outs = 9
        inlets = {'broth: TAL':3}
        outlets = {'TAL':8}
        boiler = [0]
        wastewater = [1, 2, 7]
        ignored_HXN = ['H401', 'C401', 'S403', 'H420']
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )

def create_TAL_cooled_separation_solubility_exploit_process(ID='TAL_cooled_separation'):
    sys = create_TAL_separation_solubility_exploit_process()
    sys.simulate()
    f = sys.flowsheet
    # at the baseline, no evaporator before recycle as heating would decarboxylate TAL
    S403 = Splitter('S403', 
                        ins=sys-2, # recycled supernatant, with or without evaporation
                        outs=('S403_recycled_supernatant', 'S403_to_WWT'),
                        split=0., # optimal split=0.
                        )
    
    @S403.add_specification(run=False)
    def S403_spec():
        S403._run()
        for i in S403.outs: i.phase = 'l'
    S403-0-2-sys
    
    H420 = HXutility('H420', 
                         ins=sys-4, # solid TAL
                         outs='cooled_solid_TAL', 
                         T=273.15+25.,)
    
    
    TAL_cooled_separation_sys = System.from_units(ID, list(sys.units) + [H420, S403])
    TAL_cooled_separation_sys.simulate(update_configuration=True)
    
    return TAL_cooled_separation_sys



# -*- coding: utf-8 -*-
"""
Created on Tue Oct 17 15:12:56 2024

@author: sarangbhagwat
"""

__all__ = ('feedstocks', 'products', 
           'model_static_queries', 'model_static_changes', 
           'model_dynamic_queries', 'model_dynamic_changes')

#%% initial
feedstocks = [
    'dextrose monohydrate',
    'corn',
    'sugarcane',
    'sweet sorghum',
    'corn stover',
    'miscanthus',
    'switchgrass',
    'wheat straw',
    ]

products = [
    'glacial acrylic acid', 'acrylic acid',
    'potassium sorbate', 'sorbic acid',
    'sodium 3-hydroxypropionate', '3-HP salt'
    'lactic acid', 'lactate',
    'succinic acid', 'succinate',
    'ethanol',
    ]

#%% static interactions
model_static_queries = [ # queries common to any system, or for which the dynamic aspect can be handled in AutoSynthesis
    # TEA
    'minimum product selling price',
    'installed cost',
    'total capital cost',
    'breakdown of capital cost contributions',
    'annual operating cost',
    'breakdown of annual operating cost contributions',
    'breakdown of utility demands',
    'variable operating cost',
    'fixed operating cost',
    'electric power consumption',
    'electric power production'
    'TEA year',
    'prices',
    # LCA
    'carbon intensity',
    'breakdown of carbon intensity contributions',
    'fossil energy consumption',
    'breakdown of fossil energy consumption contributions',
    'impact characterization factors'
    ]

model_static_changes = [
    'fermentation yield (g/g)',
    'fermentation titer (g/L)',
    'fermentation productivity (g/L/h)',
    'fermentation co-product yields',
    'feedstock capacity',
    'production capacity',
    ]

#%% dynamic interactions
# note these will be dynamically generated for each new system; below items 
# are examples only


model_unit_name_examples = [
    'D401',
    'R302',
    'C601',
    'D301',
    'R301',
    'fermentation reactor',
    ]

model_unit_attribute_examples = [
    'material balance',
    'installed costs',
    'power utility',
    'heat utilities',
    'CO2 sparging rate',
    'all reactions',
    'glucose to 3-HP reaction',
    'glucose to acetic acid reaction',
    'light key recovery',
    'heavy key recovery',
    ]

model_stream_name_examples = [
    'feedstock',
    'acrylic acid',
    'sulfuric acid for reacidulation',
    'lime for neutralization',]

model_stream_attribute_examples = [
    'price',
    'cost',
    'mass flow',
    'molar flow',
    'volumetric flow',
    ]

model_dynamic_queries = []
import itertools
for i in itertools.product(model_unit_name_examples, model_unit_attribute_examples):
    model_dynamic_queries.append(i[0] + ' - ' + i[1])
for i in itertools.product(model_stream_name_examples, model_stream_attribute_examples):
    model_dynamic_queries.append(i[0] + ' - ' + i[1])

model_dynamic_changes = []



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarang.bhagwat.git@gmail.com>
# 
# This module is under the UIUC open-source license. See 
# https://github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE
# for license details.
import autosynthesis

def create_biorefinery(feedstock, product, choice=None):
    sys = autosynthesis.process_blocks.get_system_block_based(feedstock=feedstock,
                                                        product=product,
                                                        choice=choice)
    return sys

def draw_plot(plot_type, sys, model):
    if plot_type=='process flowsheet':
        sys.diagram('cluster')
    elif plot_type in ('baseline TEA results', 'TEA results'):
        pass
    elif plot_type in ('baseline LCA results', 'LCA results'):
        pass

def get_attribute_or_parameter(attribute, sys, model=None):
    pass

def update_parameter(parameter, value, model=None):
    pass

def run_uncertainty_analysis(model):
    pass

def run_sensitivity_analysis(model):
    pass




# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 15:02:24 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biorefineries.sugarcane import create_juicing_system_up_to_clarification

__all__ = ('SugarcaneJuicing',)

class SugarcaneJuicing(ProcessBlock):
    
    def __init__(self, ID='sugarcane_juicing',):
        create_function = create_juicing_system_up_to_clarification
        base_TEA_year = 2019
        N_ins = 4
        N_outs = 2
        inlets = {'sugarcane':0, 'sweet sorghum':0}
        outlets = {'juice: sucrose, glucose, fructose':0}
        boiler = [1, 2]
        wastewater = []
        ignored_HXN = []
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Tue Oct 15 00:18:30 2024

@author: sarangbhagwat
"""
import networkx as nx
import graphviz as gv
from matplotlib import pyplot as plt

from .feedstock_to_sugars import dextrose_monohydrate_receiving, cane_juicing, corn_dry_grind, cellulosic_pretreatment, cellulosic_saccharification
from .sugar_fermentation import fermentation_HP, fermentation_TAL, fermentation_ethanol
from .product_separation import HP_solution_separation, HP_salt_separation, TAL_separation, ethanol_separation
from .product_upgrading import HP_solution_upgrading_acrylic_acid, TAL_upgrading_potassium_sorbate

__all__ = ('BlockSuperstructure',)

_all_process_blocks = [
    
    # feedstock_to_sugars
    dextrose_monohydrate_receiving.DextroseMonohydrateReceiving(),
    cane_juicing.SugarcaneJuicing(),
    corn_dry_grind.CornDryGrind(),
    cellulosic_pretreatment.CornstoverDiluteAcidPretreatment(),
    cellulosic_pretreatment.MiscanthusDiluteAcidPretreatment(),
    cellulosic_saccharification.CellulosicEnzymaticSaccharification(),
    
    # sugar_fermentation
    fermentation_HP.FermentationHP(),
    fermentation_TAL.FermentationTAL(),
    fermentation_ethanol.FermentationEthanol(),
    
    # product_separation
    HP_solution_separation.HPSolutionSeparationIExCR(),
    HP_solution_separation.HPSolutionSeparationHexanol(),
    HP_salt_separation.HPSaltSeparation(),
    TAL_separation.TALHotSeparation(),
    TAL_separation.TALCooledSeparation(),
    ethanol_separation.EthanolSeparation(),
    
    # product_upgrading
    HP_solution_upgrading_acrylic_acid.HPSolutionUpgradingAcrylicAcid(),
    TAL_upgrading_potassium_sorbate.TALUpgradingIPAPotassiumSorbate(),
    TAL_upgrading_potassium_sorbate.TALUpgradingTHFEthanolPotassiumSorbate(),
    ]

_all_exclusively_feedstocks = [
    'dextrose monohydrate',
    'corn',
    'sugarcane',
    'sweet sorghum',
    'corn stover',
    'miscanthus',
    'switchgrass',
    'wheat straw',
    ]

_all_exclusively_products = [
    'glacial acrylic acid',
    'ethanol',
    'potassium sorbate',
    'sodium 3-hydroxypropionate'
    ]

class BlockSuperstructure():
    
    def __init__(self, ID='DefaultBlockSuperstructure', 
                 process_blocks=_all_process_blocks,
                 exclusively_feedstocks=_all_exclusively_feedstocks,
                 exclusively_products=_all_exclusively_products,
                 ):
        self.ID = ID
        self.process_blocks = {i.ID: i for i in process_blocks} if isinstance(process_blocks, list) else process_blocks
        self._graph = None
        self.exclusively_feedstocks = _all_exclusively_feedstocks
        self.exclusively_products = _all_exclusively_products
    
    @property
    def graph(self): return self._graph
    
    def create_graph(self):
        G = nx.DiGraph()
        process_blocks = self.process_blocks
        # process_blocks_keys = process_blocks.keys()
        # nodes = [i.ID for i in process_blocks_keys]
        process_blocks_items = process_blocks.items()
        
        for ki, vi in process_blocks_items:
            for kj, vj in process_blocks_items:
                if not ki==kj:
                    for ei in vi.out_edges:
                        for ej in vj.acceptable_in_edges:
                            if ei==ej: 
                                G.add_edge(ki, ei) # process block 1 to intermediate/product
                                G.add_edge(ei, kj) # intermediate/product to process block 2
                                
        
        for feed in self.exclusively_feedstocks:
            for ki, vi in process_blocks_items:
                for ei in vi.acceptable_in_edges:
                    if feed==ei: G.add_edge(feed, ki, name=ei)
        
        for prod in self.exclusively_products:
            for ki, vi in process_blocks_items:
                for ei in vi.out_edges:
                    if prod==ei: G.add_edge(ki, prod, name=ei)
                    
        self._graph = G
        return G
    
    def draw_graph(self, draw_edge_labels=False):
        G = self._graph
        colors = self._get_colors(G)
        # G = nx.relabel_nodes(G, 
        #                      mapping={i:i.replace(':', '--') for i in list(G.nodes)}, 
        #                      copy=True)
        # pos = nx.nx_pydot.pydot_layout(G)
        pos = nx.spring_layout(G, k=1., iterations=100)
        plt.figure()
        nx.draw(
            G, pos, edge_color='black', width=1, linewidths=1,
            node_size=500, node_color=colors, alpha=0.9,
            font_size =7,
            labels={node: node for node in G.nodes()}
        )
        if draw_edge_labels:
            nx.draw_networkx_edge_labels(
                G, pos,
                edge_labels=nx.get_edge_attributes(G, 'name', default=''),
                font_color='blue'
            )
        plt.axis('off')
        plt.show()
        
        # draw using graphviz
        attrs = {}
        for i,col in zip(list(G.nodes), colors):
            attrs[i] = {}
            attrs[i]['style']='filled'
            attrs[i]['fillcolor']=col
        nx.set_node_attributes(G, attrs)
        
        A = nx.drawing.nx_agraph.to_agraph(G)
        A.layout('dot')
        A.draw('block_superstructure.png')
    
    def _get_colors(self, G):
        process_block_keys = self.process_blocks.keys()
        exclusively_feedstocks = self.exclusively_feedstocks
        colors = []
        for i in G.nodes():
            if i in process_block_keys: # process block
                colors.append('#63C6CE')
            elif i in exclusively_feedstocks: # feedstock
                colors.append('#7BBD84')
            else: # intermediates and products
                colors.append('#F8858A')
        return colors

    def get_all_paths(self, A, B):
        return list(nx.all_simple_paths(self._graph, A, B))
    
    def get_and_draw_all_paths(self, A, B):
        all_paths = self.get_all_paths(A, B)
        G = nx.DiGraph()
        for p in all_paths:
            for i in range(len(p)-1):
                G.add_edge(p[i], p[i+1])
        pos = nx.spring_layout(G, k=1., iterations=100)
        colors = self._get_colors(G)
        plt.figure()
        nx.draw(
            G, pos, edge_color='black', width=1, linewidths=1,
            node_size=500, node_color=colors, alpha=0.9,
            labels={node: node for node in G.nodes()},
            node_shape='s', 
            # bbox=dict(facecolor="skyblue", 
            #           edgecolor='black', 
            #           boxstyle='round,pad=0.2')
        )
        plt.axis('off')
        plt.show()
        
        # draw using graphviz
        attrs = {}
        for i,col in zip(list(G.nodes), colors):
            attrs[i] = {}
            attrs[i]['style']='filled'
            attrs[i]['fillcolor']=col
        nx.set_node_attributes(G, attrs)
        
        A = nx.drawing.nx_agraph.to_agraph(G)
        A.layout('dot')
        A.draw('all_paths_feed_to_product.png')
        
        return G
        
        


# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 15:33:50 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biorefineries.cornstover import create_dilute_acid_pretreatment_system
from biorefineries.miscanthus.systems import feedstock_kwargs as miscanthus_kwargs
from thermosteam import Stream

__all__ = ('CornstoverDiluteAcidPretreatment',
           'MiscanthusDiluteAcidPretreatment')

class CornstoverDiluteAcidPretreatment(ProcessBlock):
    
    def __init__(self, ID='cornstover_cellulosic_dilute_acid_pretreatment'):
        create_function = create_dilute_acid_pretreatment_system
        base_TEA_year = 2007
        N_ins = 3
        N_outs = 2
        inlets = {'corn stover': 0}
        outlets = {'pretreated cellulosic stream':0}
        boiler = []
        wastewater = [1]
        ignored_HXN = []
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )


class MiscanthusDiluteAcidPretreatment(ProcessBlock):
    
    def __init__(self, ID='cornstover_cellulosic_dilute_acid_pretreatment'):
        create_function = self.miscanthus_DAP_create_function
        base_TEA_year = 2007
        N_ins = 3
        N_outs = 2
        inlets = {'miscanthus': 0}
        outlets = {'pretreated cellulosic stream':0}
        boiler = []
        wastewater = [1]
        ignored_HXN = []
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )
        
        self.miscanthus_default_composition = Stream(**miscanthus_kwargs)
        
    def miscanthus_DAP_create_function(self, ID):
        sys = create_dilute_acid_pretreatment_system('miscanthus_cellulosic_dilute_acid_pretreatment_sys')
        feedstock = sys.ins[self.inlets['miscanthus']]
        original_F_mass = feedstock.F_mass
        feedstock.copy_like(self.miscanthus_default_composition)
        feedstock.F_mass = original_F_mass
        feedstock.ID = 'miscanthus'
        return sys
    


# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 16:17:27 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biorefineries.HP.process_areas import create_HP_separation_improved_process_HP_product

__all__ = ('HPSaltSeparation',)

class HPSaltSeparation(ProcessBlock):
    def __init__(self, ID='HP_salt_separation', primary_inlet_name='broth: 3-HP'):
        self._primary_inlet_name = primary_inlet_name
        create_function = create_HP_separation_improved_process_HP_product
        base_TEA_year = 2016
        N_ins = 6
        N_outs = 8
        inlets = {'broth: 3-HP':0}
        outlets = {'sodium 3-hydroxypropionate':0}
        boiler = [1]
        wastewater = [3, 4, 5, 6, 7]
        ignored_HXN = []
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 17:51:28 2024

@author: sarangbhagwat
"""

import thermosteam as tmo
from biosteam import System, SystemFactory, Mixer, HeatUtility, StorageTank, Pump, ConveyingBelt, ChilledWaterPackage, HeatExchangerNetwork, create_high_rate_wastewater_treatment_system, main_flowsheet
from biorefineries.cellulosic import create_facilities
from biorefineries.HP.chemicals_data import HP_chemicals
from biorefineries.TAL.chemicals_data import TAL_chemicals
from ._block_superstructure import BlockSuperstructure
# from biosteam.exceptions import UndefinedChemicalAlias

tmo_settings = tmo.settings
set_thermo = tmo_settings.set_thermo
Chemicals = tmo.Chemicals

#%% Consolidating multiple Chemicals/CompiledChemicals objects into a single CompiledChemicls object

def _get_consolidated_chemicals(list_of_compiled_chemicals):
    chems_brs_compiled = list_of_compiled_chemicals
    chems_brs = [Chemicals(cbr) for cbr in chems_brs_compiled]


    chems_flattened = Chemicals(chems_brs[0])
    chems_flattened.extend([i for i in chems_brs_compiled[0] if i not in chems_flattened])

    for i in range(1, len(chems_brs)):
        cbr = chems_brs[i]
        cbrc = chems_brs_compiled[i]
        # cbr.extend([i for i in cbrc if i not in cbr]) # add missing chemicals
        # print(chems_flattened, [i for i in cbrc if i not in chems_flattened])
        # chems_flattened.extend([i for i in cbrc if i not in chems_flattened])
        
        for i in cbrc:
            if i not in chems_flattened:
                append=True
                for j in chems_flattened:
                    if i.ID.lower() in [c.lower() for c in j.synonyms]:
                        append=False
                        break
                if append:
                    try:
                        chems_flattened.append(i)
                    except:
                        pass
                    

    chems_flattened.compile()

    # chems_flattened.set_alias('DiammoniumSulfate', '(NH4)2SO4')
    # chems_flattened.set_alias('DiammoniumSulfate', 'AmmoniumSulfate')

    for i in list(chems_brs_compiled[0].chemical_groups):
        chems_flattened.define_group(i, [c.ID for c in chems_brs_compiled[0].__dict__[i]])
    
    return chems_flattened

chemicals_default = _get_consolidated_chemicals([HP_chemicals, TAL_chemicals])

#%% Generating units for storage of feed and product streams
def create_feed_and_product_storage_units(feeds, products, area=600,
                                 product_storage_tau=24.*7., # default to 1-week product storage
                                 include_empty_feeds=False,
                                 include_empty_products=False,
                                 wastewater_area=500,):
    units = []
    i = 1
    for feed in feeds:
        sink = feed.sink
        sink_index = sink.ins.index(feed)
        if (not feed.F_mol==0.) or include_empty_feeds:
            # print(feed.source, feed.ID, feed.sink)
            if is_solid(feed):
                str_num = str(area+i)
                pump_unit = Pump('P'+str_num, ins='', outs='', thermo=feed.thermo)
                pump_unit-0-sink_index-sink
                storage_unit = StorageTank('T'+str_num, ins=feed, thermo=feed.thermo)
                storage_unit-0-0-pump_unit
                units += [storage_unit, pump_unit]
                # storage_unit.ins[0].price = feed.price
                # feed.price = 0.
            elif is_liquid(feed) and not feed.imol['Water']/feed.F_mol==1:
                str_num = str(area+i)
                pump_unit = Pump('P'+str_num, ins='', outs='', thermo=feed.thermo)
                pump_unit-0-sink_index-sink
                storage_unit = StorageTank('T'+str_num, ins=feed, thermo=feed.thermo)
                storage_unit-0-0-pump_unit
                units += [storage_unit, pump_unit]
                # storage_unit.ins[0].price = feed.price
                # feed.price = 0.
            elif is_gaseous(feed):
                pass
            i+=1

    for product in products:
        # source = product.source
        # source_index = source.outs.index(product)
        if (not product.F_mol==0.) or include_empty_products:
            # print(product.source, product.ID, product.sink)
            if is_solid(product):
                str_num = str(area+i)
                storage_unit = StorageTank('T'+str_num, ins=product, tau=product_storage_tau, thermo=feed.thermo)
                pump_unit = Pump('P'+str_num, ins=storage_unit-0, thermo=feed.thermo)
                units += [storage_unit, pump_unit]
                pump_unit.outs[0].price = product.price
                product.price = 0.
            elif is_liquid(product) and not product.imol['Water']/product.F_mol==1\
                and not (is_from_unit_in_area(product, wastewater_area)): # as storage units are created only for no_facilities_sys, this condition is 
                                                                          # not really necessary (even though storage is created after WWT), might remove later
                str_num = str(area+i)
                storage_unit = StorageTank('T'+str_num, ins=product, tau=product_storage_tau, thermo=feed.thermo)
                pump_unit = Pump('P'+str_num, ins=storage_unit-0, outs='product_'+product.ID, thermo=feed.thermo)
                units += [storage_unit, pump_unit]
                pump_unit.outs[0].price = product.price
                product.price = 0.
            elif is_gaseous(product):
                pass
            i+=1
        
    return units
    
def is_from_unit_in_area(stream, area):
    source_ID = stream.source.ID
    # 3-digit area number
    if not source_ID[-4] in ['1', '2', '3', '4', '5', '6', '7', '8', '9', '0']:
        if source_ID[-3]==str(area)[0]:
            return True
        else:
            return False
    # 4-digit area number
    else:
        if source_ID[-4]==str(area)[0] and source_ID[-3]==str(area)[1]:
            return True
        else:
            return False
    
def is_solid(stream, cutoff_massfrac=0.5):
    if stream.phase=='s':
        return True
    solid_phase_ref_chems = [i.ID for i in stream.chemicals if i.phase_ref=='s']
    if stream.F_mol and stream.imass[solid_phase_ref_chems].sum()/stream.F_mass>cutoff_massfrac:
        return True
    else:
        return False

def is_liquid(stream, cutoff_massfrac=0.5):
    liquid_phase_ref_chems = [i.ID for i in stream.chemicals if i.phase_ref=='l']
    if stream.F_mol and stream.imass[liquid_phase_ref_chems].sum()/stream.F_mass>cutoff_massfrac:
        return True
    else:
        return False

def is_gaseous(stream, cutoff_massfrac=0.5, cutoff_P=101325):
    if stream.phase=='g':
        return True
    gas_phase_ref_chems = [i.ID for i in stream.chemicals if i.phase_ref=='l']
    if stream.F_mol and stream.imass[gas_phase_ref_chems].sum()/stream.F_mass>cutoff_massfrac\
        and stream.P>=cutoff_P:
        return True
    else:
        return False

#%% Generating a system by process block-based synthesis

def get_system_block_based(feedstock, product, 
                           block_superstructure=None, 
                           choice=None, 
                           chemicals=None,
                           draw=True,
                           new_facilities=True,
                           new_storage=True,
                           storage_for_empty_feeds=False,
                           storage_for_empty_products=False,
                           TEA_year=2019):
    
    if block_superstructure is None: block_superstructure = BlockSuperstructure()
    if chemicals is None: chemicals = chemicals_default
    # if not chemicals:
    #     chemicals = chems
    set_thermo(chemicals)
    
    u = main_flowsheet.unit
    BSS = block_superstructure
    BSS.create_graph()
    if draw: BSS.draw_graph()
    all_paths = BSS.get_all_paths(feedstock, product)
    if draw: BSS.get_and_draw_all_paths(feedstock, product)
    path = None
    
    if len(all_paths)>1: # more than one possible path
        if choice is None: # if user has not entered a choice of path
            print('\nMultiple paths possible; enter value for "choice" argument from the following integers:\n')
            for i in range(len(all_paths)):
                p = str(all_paths[i]).replace("'", "").replace("[", "").replace("]", "")
                print(f'{i}: {p}')
            return all_paths
        else:
            path = all_paths[choice]
    else:
        if not choice:
            path = all_paths[0] # only one possible path
    
    process_blocks = BSS.process_blocks
    process_block_keys = process_blocks.keys()
    all_blocks = []
    
    for p in path:
        if p in process_block_keys: 
            all_blocks.append(process_blocks[p])
    
    # Initialize and connect process blocks
    for b in all_blocks: b.create()
                
    for i in range(len(all_blocks)-1):
        all_blocks[i].make_all_possible_connections(all_blocks[i+1])

    # Initialize and simulate no-facilities system; 
    # also update TEA year for all blocks
    units = []
    for i in all_blocks: 
        units+= list(i.system.units)
        i.TEA_year = TEA_year

    no_facilities_sys = System.from_units('no_facilities_sys', units)
    no_facilities_sys.simulate(update_configuration=True)
    
    # SystemFactory to initialize and connect facilities
    
    @SystemFactory(ID = 'facilities_only_sys')
    def create_facilities_only_sys(ins, outs, wastewater_streams=[], boiler_streams=[], ignored_HXN_units=[]):
        # Wastewater treatment
        M501 = Mixer('M501', ins=wastewater_streams)
        
        @M501.add_specification(run=False)
        def M501_acid_base_removal_spec():
            for i in M501.ins:
                i.imol['NaOH','H2SO4'] = 0.
            M501._run()
        
        wastewater_treatment_sys = create_high_rate_wastewater_treatment_system(
            ins=M501-0, 
            area=500, 
            mockup=False,
            # skip_AeF=True,
            )
        
        tmo.settings.thermo.chemicals.set_synonym('BoilerChems', 'DAP')
        
        
        # Mix solid wastes to boiler turbogenerator
        M510 = Mixer('M510', ins=boiler_streams,
                                outs='wastes_to_boiler_turbogenerator')
        @M510.add_specification(run=True)
        def M510_spec():
            for i in M510.ins: i.phase='l'
            
        MX = Mixer(900, ['', ''])
        
        M503 = u.M503
        @M503.add_specification(run=False)
        def M503_spec():
            for i in M503.ins: i.phase='l'
            M503._run()
            for j in M503.outs: j.phase='l'
            
        # other facilities
        
        create_facilities(
            solids_to_boiler=M510-0,
            gas_to_boiler=wastewater_treatment_sys-1,
            process_water_streams=[
             i for i in no_facilities_sys.feeds if i.get_molar_fraction('Water')==1.
             ],
            feedstock=all_blocks[0].inlet(feedstock), #!!! may need to update later if adding feedstock handling outside process blocks
            RO_water=wastewater_treatment_sys-2,
            recycle_process_water=MX-0,
            BT_area=700,
            area=900,
        )
        
        # Chilled water processing
        CWP803 = ChilledWaterPackage('CWP803', agent=HeatUtility.cooling_agents[-2])
        
        # Heat exchanger network
        HXN = HeatExchangerNetwork('HXN1001',
                                    ignored=ignored_HXN_units,
                                    cache_network=False,
                                    )
        
        def HXN_no_run_cost():
            HXN.heat_utilities = []
            HXN._installed_cost = 0.
    
    # Get all streams to be diverted to wastewater treatment and boiler,
    # and all units to be ignored in HXN synthesis
    
    wastewater_streams = []
    boiler_streams = []
    ignored_HXN_units = []
    namespace_dict = {'u':u, 'ignored_HXN_units':ignored_HXN_units}
    for i in all_blocks: 
        wastewater_streams += [i.system.outs[j] for j in i.wastewater]
        boiler_streams += [i.system.outs[j] for j in i.boiler]
        for j in i.ignored_HXN:
            namespace_dict.update({'j':j})
            try:
                exec('ignored_HXN_units.append(u.' + j + ')', namespace_dict)
            except:
                breakpoint()
        
    # Create facilities-only system
    facilities_only_sys_units = []
    if new_facilities:
        facilities_only_sys = create_facilities_only_sys(wastewater_streams=wastewater_streams,
                                                         boiler_streams=boiler_streams, 
                                                         ignored_HXN_units=ignored_HXN_units)
        facilities_only_sys_units = facilities_only_sys.units
    
    # SystemFactory to initialize and connect storage units
    
    @SystemFactory(ID = 'storage_only_sys')
    def create_storage_only_sys(ins, outs, wastewater_streams=[], boiler_streams=[], ignored_HXN_units=[]):
        feeds = list(no_facilities_sys.feeds)
        products = list(no_facilities_sys.products)
        for i in wastewater_streams+boiler_streams: 
            if i in products: products.remove(i)
        feedstock_stream = all_blocks[0].inlet(feedstock)
        if feedstock_stream in feeds: feeds.remove(feedstock_stream)
        feed_storage_units = create_feed_and_product_storage_units(feeds, products,
                                                                   include_empty_feeds=storage_for_empty_feeds,
                                                                   include_empty_products=storage_for_empty_products,
                                                                   )
    
    # Create storage-only system
    storage_only_sys_units = []
    if new_storage:
        storage_only_sys = create_storage_only_sys(wastewater_streams=wastewater_streams,
                                                   boiler_streams=boiler_streams, 
                                                   ignored_HXN_units=ignored_HXN_units)
        storage_only_sys_units = storage_only_sys.units
    
    # Create full system
    full_sys = System.from_units('full_sys', 
                                 list(no_facilities_sys.units) + 
                                 facilities_only_sys_units +
                                 storage_only_sys_units)
    
    full_sys.simulate(update_configuration=True)
    if draw: full_sys.diagram('cluster')
    
    for i in range(3): full_sys.simulate()
    # full_sys.feedstock_streams = [all_blocks[0].inlet(feedstock)]
    
    return full_sys




# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarang.bhagwat.git@gmail.com>
# 
# This module is under the UIUC open-source license. See 
# https://github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE
# for license details.
"""
"""

from .._process_block import ProcessBlock
from . import feedstock_to_sugars
from .feedstock_to_sugars import *
from . import sugar_fermentation
from .sugar_fermentation import *
from . import product_separation
from .product_separation import *
from . import product_upgrading
from .product_upgrading import *
from._block_superstructure import BlockSuperstructure
from._block_based_system import get_system_block_based

__all__ = (
    'ProcessBlock',
    *feedstock_to_sugars.__all__,
    *sugar_fermentation.__all__,
    *product_separation.__all__,
    *product_upgrading.__all__,
    'BlockSuperstructure',
    'get_system_block_based',
)

# from .._process_block import ProcessBlock
# from .feedstock_to_sugars import cane_juicing, corn_dry_grind, cellulosic_pretreatment_saccharification
# from .sugar_fermentation import fermentation_HP, fermentation_TAL, fermentation_ethanol
# from .product_separation import HP_solution_separation, TAL_separation, ethanol_separation
# from .product_upgrading import HP_solution_upgrading_acrylic_acid, TAL_upgrading_potassium_sorbate
# from._block_superstructure import BlockSuperstructure
# from._block_based_system import get_system_block_based

# __all__ = (
#     'ProcessBlock',
#     *cane_juicing.__all__,
#     *corn_dry_grind.__all__,
#     *cellulosic_pretreatment_saccharification.__all__,
#     *fermentation_HP.__all__,
#     *fermentation_TAL.__all__,
#     *fermentation_ethanol.__all__,
#     *HP_solution_separation.__all__,
#     *TAL_separation.__all__,
#     *ethanol_separation.__all__,
#     *HP_solution_upgrading_acrylic_acid.__all__,
#     *TAL_upgrading_potassium_sorbate.__all__,
#     'BlockSuperstructure',
#     'get_system_block_based',
# )



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Mon Oct 14 17:04:04 2024

@author: sarangbhagwat
"""

from .. import ProcessBlock
from biorefineries.TAL.process_areas import create_TAL_to_sorbic_acid_upgrading_process, create_TAL_to_sorbic_acid_upgrading_process_THF_Ethanol

__all__ = ('TALUpgradingIPAPotassiumSorbate', 'TALUpgradingTHFEthanolPotassiumSorbate')


class TALUpgradingIPAPotassiumSorbate(ProcessBlock):
    def __init__(self, ID='TAL_upgrading_IPA_potassium_sorbate', primary_inlet_name='TAL'):
        self._primary_inlet_name = primary_inlet_name
        create_function = create_TAL_to_sorbic_acid_upgrading_process
        base_TEA_year = 2019
        N_ins = 7
        N_outs = 8
        inlets = {i:0 for i in ['hot TAL', 'TAL solution', 'TAL']}
        outlets = {'potassium sorbate':0}
        boiler = [1]
        wastewater = [6, 7]
        ignored_HXN = ['R401', 'R402', 'R403']
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )


class TALUpgradingTHFEthanolPotassiumSorbate(ProcessBlock):
    def __init__(self, ID='TAL_upgrading_THF_ethanol_potassium_sorbate', primary_inlet_name='TAL'):
        self._primary_inlet_name = primary_inlet_name
        create_function = create_TAL_to_sorbic_acid_upgrading_process_THF_Ethanol
        base_TEA_year = 2019
        N_ins = 8
        N_outs = 10
        inlets = {i:0 for i in ['hot TAL', 'TAL solution', 'TAL']}
        outlets = {'potassium sorbate':0}
        boiler = [1]
        wastewater = [7, 8, 9]
        ignored_HXN = ['R401', 'R402', 'R403']
        
        ProcessBlock.__init__(self, ID=ID, 
                     create_function=create_function, 
                     base_TEA_year=base_TEA_year,
                     inlets=inlets, 
                     outlets=outlets,
                     boiler=boiler,
                     wastewater=wastewater,
                     ignored_HXN=ignored_HXN,
                     N_ins=N_ins,
                     N_outs=N_outs,
                     )



# -*- coding: utf-8 -*-
"""
Created on Sat Nov 12 20:30:00 2022

@author: sarangbhagwat
"""

from setuptools import setup, find_packages

setup(
    name='autosynthesis',
    packages=find_packages(),
    version='0.0.31',    
    description='A toolkit for automated synthesis of biorefinery processes including pretreatment, conversion, separation, and upgrading.',
    url='https://github.com/sarangbhagwat/autosynthesis',
    download_url='https://github.com/sarangbhagwat/autosynthesis.git',
    author='Sarang S. Bhagwat',
    author_email='sarangbhagwat.developer@gmail.com',
    license='MIT',
    # packages=['contourplots'],
    python_requires='>=3.9',
    platforms=['Windows', 'Mac', 'Linux'],
    install_requires=[
                      'biosteam>=2.33.2',
                      'xlsxwriter',
                      ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: Linux',
        'Operating System :: Unix',
        'Programming Language :: Python :: 3.9',
    ],
)



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarang.bhagwat.git@gmail.com>
# 
# This module is under the UIUC open-source license. See 
# https://github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE
# for license details.
"""
"""

from . import cane_juicing
from .cane_juicing import *
from . import corn_dry_grind
from .corn_dry_grind import *
from . import cellulosic_pretreatment
from .cellulosic_pretreatment import *
from . import cellulosic_saccharification
from .cellulosic_saccharification import *
from . import dextrose_monohydrate_receiving
from .dextrose_monohydrate_receiving import *



__all__ = (
    *cane_juicing.__all__,\
    *corn_dry_grind.__all__,
    *cellulosic_pretreatment.__all__,
    *cellulosic_saccharification.__all__,
    *dextrose_monohydrate_receiving.__all__,
)



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarangb2@illinois.edu>
# 
# This module is under the UIUC open-source license. See 
# github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE.txt
# for license details.
"""
Created on Thu May  8 23:52:21 2025

@author: sarangbhagwat
"""
import biosteam as bst
from ._process_block import GDP_index, chem_index

__all__ = ('TEAFactory',)

CEPCI_by_year = bst.units.design_tools.cost_index.CEPCI_by_year

#%%
def BlockBasedTEA():
    



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarang.bhagwat.git@gmail.com>
# 
# This module is under the UIUC open-source license. See 
# https://github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE
# for license details.
"""
"""

from . import fermentation_HP
from .fermentation_HP import *
from . import fermentation_TAL
from .fermentation_TAL import *
from . import fermentation_ethanol
from .fermentation_ethanol import *


__all__ = (
    *fermentation_HP.__all__,\
    *fermentation_TAL.__all__,
    *fermentation_ethanol.__all__,
)



# -*- coding: utf-8 -*-
# AutoSynthesis: The Automated Process Synthesis & Design package.
# Copyright (C) 2022-, Sarang Bhagwat <sarang.bhagwat.git@gmail.com>
# 
# This module is under the UIUC open-source license. See 
# https://github.com/sarangbhagwat/autosynthesis/blob/main/LICENSE
# for license details.
"""
"""

from . import HP_solution_upgrading_acrylic_acid
from .HP_solution_upgrading_acrylic_acid import *
from . import TAL_upgrading_potassium_sorbate
from .TAL_upgrading_potassium_sorbate import *



__all__ = (
    *HP_solution_upgrading_acrylic_acid.__all__,\
    *TAL_upgrading_potassium_sorbate.__all__,
)
